=================
Django Markdowner
=================

.. image:: https://img.shields.io/badge/python-3.6+-green.svg?
    :target: https://www.python.org/

.. image:: https://img.shields.io/pypi/l/django-markdowner.svg
    :target: https://github.com/LeCuay/django-markdowner/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/django-markdowner.svg
    :target: https://pypi.python.org/pypi/django-markdowner/
    :alt: Latest PyPI version

.. image:: https://travis-ci.com/LeCuay/django-markdowner.svg?branch=master
    :target: https://travis-ci.com/LeCuay/django-markdowner
    :alt: Build Status

Django Markdowner allows you to parse Markdown files into Django Templates.

Requirements
============

Django Markdowner requires Django 1.11 or Django 2+.

Getting It
==========

You can get Django Markdowner by using pip::
    $ pip install django-markdowner
